@@ -1,4 +1,4 @@
-import sft
+from sub_formater import sft
 
 
 def main():
